%global libname libnmstate

Summary:        Declarative network manager API
Name:           nmstate
Version:        2.2.0
Release:        6%{?dist}
License:        LGPLv2+
URL:            https://github.com/%{name}/%{name}
Source0:        %{url}/releases/download/v%{version}/%{name}-%{version}.tar.gz
# download with `cargo vendor` with cargo.toml, then package them up with `tar cvf`
Source1:        %{name}-%{version}-vendor.tar.gz
Patch3001:      nmstate-2.2.0-add-loongarch64-support-for-linux-raw-sys.patch
Patch3002:      nmstate-2.2.0-add-loongarch64-support-for-nix.patch

BuildRequires:  python3-devel python3-setuptools systemd-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  rust-toolset

%description
Nmstate is a library with an accompanying command line tool that manages host
networking settings in a declarative manner and aimed to satisfy enterprise
needs to manage host networking through a northbound declarative API and multi
provider support on the southbound.


%package libs
Summary:        C binding of nmstate
License:        ASL 2.0
Recommends:     NetworkManager
Recommends:     NetworkManager-config-server

%description libs
C binding of nmstate.

%package devel
Summary:        Development files for nmstate
License:        ASL 2.0
Group:          Development/Libraries
Requires:       %{name}-libs = %{version}-%{release}

%description devel
Development files of nmstate C binding.

%package static
Summary:        Static development files for nmstate
Group:          Development/Libraries
Requires:       %{name}-devel = %{version}-%{release}

%description static
Static C library bindings for nmstate.

%package -n python3-%{libname}
Summary:        nmstate Python 3 API library
Requires:       %{name}-libs = %{version}-%{release}
Recommends:     NetworkManager
Recommends:     NetworkManager-config-server
Recommends:     (nmstate-plugin-ovsdb if openvswitch)
Suggests:       NetworkManager-ovs
Suggests:       NetworkManager-team
Provides:       nmstate-plugin-ovsdb = %{version}-%{release}

%description -n python3-%{libname}
This package contains the Python 3 library for Nmstate.

%prep
%setup

pushd rust
# cargo_prep will now generate a file with the same name '.cargo/config.toml', so assign _FLAGS first
_FLAGS=`sed -ne 's/rustflags = "\(.\+\)"/\1/p' .cargo/config.toml`

%cargo_prep -V 1

sed -i -e "s/rustflags = \[\(.\+\), \]$/rustflags = [\1, \"$_FLAGS\"]/" \
    .cargo/config.toml

popd
%autopatch -p1


%build
pushd rust/src/python
%py3_build
popd

pushd rust
%cargo_build
popd

%install
env SKIP_PYTHON_INSTALL=1 \
    PREFIX=%{_prefix} \
    LIBDIR=%{_libdir} \
    SYSCONFDIR=%{_sysconfdir} \
    %make_install

pushd rust/src/python
%py3_install
popd

%files
%doc README.md
%doc examples/
%{_bindir}/nmstatectl
%{_bindir}/nmstate-autoconf
%{_unitdir}/nmstate.service
%dir %{_sysconfdir}/%{name}
%{_sysconfdir}/%{name}/README
%{_mandir}/man8/nmstatectl.8*
%{_mandir}/man8/nmstate-autoconf.8*
%{_mandir}/man8/nmstate.service.8*

%files libs
%license rust/LICENSE
%{_libdir}/libnmstate.so.*

%files devel
%{_libdir}/libnmstate.so
%{_includedir}/nmstate.h
%{_libdir}/pkgconfig/nmstate.pc

%files -n python3-%{libname}
%license LICENSE
%{python3_sitelib}/%{libname}
%{python3_sitelib}/%{name}-*.egg-info/

%files static
%{_libdir}/libnmstate.a


%changelog
* Wed Jul 17 2024 Rebuild Robot <rebot@opencloudos.org> - 2.2.0-6
- [Type] bugfix
- [DESC] Rebuilt for rust-toolset, assign _FLAGS first

* Thu Jun 6 2024 Pengda Dou <doupengda@loongson.cn> - 2.2.0-5
- [Type] other
- [DESC] add support for loongarch64

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.2.0-4
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.2.0-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.2.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Mar 29 2023 cunshunxia <cunshunxia@tencent.com> - 2.2.0-1
- initial build
